NmError subclass: #NmCannotResolveName
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-NameResolver'!

!NmCannotResolveName methodsFor: 'actions-resolving' stamp: 'MU 10/22/2002 17:06'!
resolve: name
	^self resolve: name ifAbsent: [ | ipAddressOrNil |
	
	
	ipAddressOrNil _ NetNameResolver addressForName: name timeout: 20.
	ipAddressOrNil ifNil: [NmCannotResolveName signal: name].
	
	NetNameResolver stringFromAddress: ipAddressOrNil
	
	
	] ! !


Object subclass: #NmNameResolver
	instanceVariableNames: 'nameToIpDictionary '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-NameResolver'!

!NmNameResolver methodsFor: 'initialize-release' stamp: 'ns 1/23/2003 15:33'!
initFromCSVString: csvString 
	| stream |
	nameToIpDictionary _ Dictionary new.
	stream _ ReadStream on: csvString.
	[stream atEnd]
		whileFalse: [| line lineStream nameString ipString | 
			line _ stream nextLine.
			(line includes: $,)
				ifTrue: [lineStream _ ReadStream on: line.
					nameString _ (lineStream upTo: $,) withBlanksTrimmed.
					ipString _ lineStream upToEnd withBlanksTrimmed.
					self nameAt: nameString put: ipString]].
	self privateRegisterLocalhostAddress! !

!NmNameResolver methodsFor: 'initialize-release' stamp: 'ns 1/23/2003 15:33'!
initialize
	nameToIpDictionary _ nil.
	self privateRegisterLocalhostAddress! !


!NmNameResolver methodsFor: 'actions-resolving' stamp: 'ns 1/23/2003 15:33'!
nameAt: name 
	^ self nameToIpDictionary
		at: name asLowercase
		ifAbsent: []! !

!NmNameResolver methodsFor: 'actions-resolving' stamp: 'ns 1/23/2003 15:33'!
nameAt: name put: ipAddressString 
	self nameToIpDictionary at: name asLowercase put: ipAddressString! !

!NmNameResolver methodsFor: 'actions-resolving' stamp: 'ns 1/23/2003 15:33'!
resolve: name 
	^ self
		resolve: name
		ifAbsent: [| ipAddressOrNil | 
			ipAddressOrNil _ NetNameResolver addressForName: name timeout: 20.
			ipAddressOrNil
				ifNil: [NmCannotResolveName signal: name].
			NetNameResolver stringFromAddress: ipAddressOrNil]! !

!NmNameResolver methodsFor: 'actions-resolving' stamp: 'ns 1/23/2003 15:33'!
resolve: name ifAbsent: aBlock 
	| ipAddress |
	ipAddress _ self nameAt: name.
	^ ipAddress isNil
		ifTrue: [aBlock value]
		ifFalse: [ipAddress]! !


!NmNameResolver methodsFor: 'converting' stamp: 'ns 1/23/2003 15:33'!
csvString
	| stream |
	stream _ WriteStream on: String new.
	self nameToIpDictionary
		keysAndValuesDo: [:key :value | 
			stream nextPutAll: key.
			stream nextPut: $,.
			stream nextPutAll: value.
			stream nextPut: Character cr].
	^ stream contents! !


!NmNameResolver methodsFor: 'accessing' stamp: 'ns 1/23/2003 15:32'!
nameToIpDictionary
	"NmNameResolver default nameToIpDictionary"
	nameToIpDictionary
		ifNil: [nameToIpDictionary _ Dictionary new].
	^ nameToIpDictionary! !

!NmNameResolver methodsFor: 'accessing' stamp: 'ns 1/23/2003 15:32'!
nameToIpDictionary: aDictionary 
	nameToIpDictionary _ aDictionary! !


!NmNameResolver methodsFor: 'private' stamp: 'ns 1/23/2003 15:32'!
privateRegisterLocalhostAddress
	self nameAt: 'localhost' put: '127.0.0.1'! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmNameResolver class
	instanceVariableNames: 'default '!

!NmNameResolver class methodsFor: 'class initialization' stamp: 'MU 10/22/2002 10:30'!
initialize
	"NmNameResolver initialize"
	default _ nil! !


!NmNameResolver class methodsFor: 'instance creation' stamp: 'MU 10/22/2002 14:23'!
new
	self shouldNotImplement! !


!NmNameResolver class methodsFor: 'updating' stamp: 'mu 10/28/2002 16:57'!
updateClientIPAddress
	"NmNameResolver updateClientIPAddress"
	| localAddress localHostname |
	localAddress _ NmUtil localAddress.
	localHostname _ NmUtil localHostname.
	NmSettings nameResolverFromInternet
		ifTrue: [| call url resp port | 
			url _ NmSettings nameResolverUrl asUrl.
			port _ NmSettings nameResolverServerPort.
			call _ (SoapCallEntry
						tcpHost: url authority
						port: (port isNil
								ifTrue: [NmSettings defaultNameResolverServerPort]
								ifFalse: [port])) newCall.
			call targetObjectURI: '/netMorph'.
			call transport: NmSettings nameResolverTransportProtocol.
			call methodName: 'updateIPAddress:of:'.
			call
				addParameter: (SoapVariable name: #ipAddress value: localAddress).
			call
				addParameter: (SoapVariable name: #hostname value: localHostname).
			resp _ call invoke.
			resp isFault
				ifTrue: [resp raiseException]
				ifFalse: [NmNameResolver default nameAt: localHostname put: localAddress]]
		ifFalse: [NmNameResolver default nameAt: localHostname put: localAddress.
			NmNameResolver store].
	Transcript cr; show: '## NmNameResolver was updated'! !


!NmNameResolver class methodsFor: 'storing/loading' stamp: 'mu 1/23/2003 19:31'!
load
	NmSettings nameResolverFromInternet
		ifTrue: [| call url resp port newEntriesCSV | 
			url _ NmSettings nameResolverUrl asUrl.
			port _ url port.
			call _ (SoapCallEntry
						tcpHost: url authority
						port: (port isNil
								ifTrue: [NmSettings defaultNameResolverServerPort]
								ifFalse: [port])) newCall.
			call targetObjectURI: '/netMorph'.
			call methodName: 'getNameResolverCSV'.
			resp _ call invoke.
			newEntriesCSV _ resp isFault
						ifTrue: [resp raiseException]
						ifFalse: [resp returnValue].
			self default initFromCSVString: newEntriesCSV].
	Transcript cr; show: '## NmNameResolver was loaded: ' , self default nameToIpDictionary printString! !

!NmNameResolver class methodsFor: 'storing/loading' stamp: 'ns 1/23/2003 18:58'!
store
	"NmNameResolver store"
	"self notImplemented"! !


!NmNameResolver class methodsFor: 'accessing' stamp: 'MU 10/22/2002 18:41'!
default
	"NmNameResolver default"
	default
		ifNil: [default _ self basicNew initialize].
	^ default! !


!NmNameResolver class methodsFor: 'examples' stamp: 'MU 10/22/2002 14:25'!
example1
	"NmNameResolver example1"
	
	| csvString nameResolver |
	csvString _ 'localhost, 127.0.0.1
smalltalk, 172.25.0.80
simula, 172.25.0.67
dylan, 172.25.0.92
'.
	nameResolver _ NmNameResolver basicNew initFromCSVString: csvString. 
	nameResolver inspect! !

NmNameResolver initialize!