Object subclass: #NmAutoWorldInfoLoader
	instanceVariableNames: 'updateProcess interval '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-Network-RPC'!

!NmAutoWorldInfoLoader methodsFor: 'actions' stamp: 'MU 10/23/2002 16:51'!
isRunning
	^updateProcess notNil	! !

!NmAutoWorldInfoLoader methodsFor: 'actions' stamp: 'MU 10/23/2002 16:43'!
load
	NmWorldMap load.
	NmNameResolver load.! !

!NmAutoWorldInfoLoader methodsFor: 'actions' stamp: 'ka 10/24/2002 18:07'!
start
	self load.
	updateProcess notNil
		ifTrue: [updateProcess terminate].
	updateProcess _ [[| currentValue nextValue | 
			currentValue _ Time millisecondClockValue.
			nextValue _ self nextMillisecondClockValue.
			(Delay forMilliseconds: nextValue - currentValue) wait.
			true]
				whileTrue: [self load]] newProcess.
	updateProcess priority: self class defaultPriority.
	updateProcess resume! !

!NmAutoWorldInfoLoader methodsFor: 'actions' stamp: 'MU 10/23/2002 16:48'!
stop
	updateProcess notNil
		ifTrue: [updateProcess terminate].
	updateProcess _ nil! !


!NmAutoWorldInfoLoader methodsFor: 'accessing' stamp: 'ka 10/23/2002 19:22'!
interval
	interval
		ifNil: [interval _ self class defaultInterval].
	^ interval! !

!NmAutoWorldInfoLoader methodsFor: 'accessing' stamp: 'ka 10/24/2002 14:38'!
interval: aValue 
	interval _ aValue.
	self start! !


!NmAutoWorldInfoLoader methodsFor: 'private' stamp: 'ns 10/2/2002 12:37'!
nextMillisecondClockValue
	^ Time millisecondClockValue + self interval truncateTo: 1000! !

!NmAutoWorldInfoLoader methodsFor: 'private' stamp: 'ns 10/8/2002 16:16'!
suspendProcess: aProcess 
	"Browser fullOnClass: ProcessBrowser selector: #suspendProcess."
	"Browser fullOnClass: ProcessBrowser class selector: #suspendProcess:. "
	aProcess isSuspended
		ifFalse: [(aProcess suspendingList isKindOf: Semaphore)
				ifTrue: [aProcess priority: Processor lowestPriority.
					aProcess suspendingList signal].
			updateProcess suspend].
	^ aProcess! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmAutoWorldInfoLoader class
	instanceVariableNames: 'soleClient updateInterval '!

!NmAutoWorldInfoLoader class methodsFor: 'class initialization' stamp: 'MU 10/23/2002 18:30'!
flushClient
	"NmAutoWorldInfoLoader flushClient."
	NmAutoWorldInfoLoader allInstances
		do: [:each | 
			each stop.
			each become: Object new].
	Smalltalk garbageCollect.
	soleClient notNil
		ifTrue: [soleClient class = self ifTrue: [soleClient stop].
			soleClient _ nil]! !


!NmAutoWorldInfoLoader class methodsFor: 'instance creation' stamp: 'MU 10/23/2002 16:46'!
default
	soleClient isNil
		ifTrue: [soleClient _ self basicNew].
	^ soleClient! !

!NmAutoWorldInfoLoader class methodsFor: 'instance creation' stamp: 'MU 10/23/2002 16:39'!
new
	self shouldNotImplement! !


!NmAutoWorldInfoLoader class methodsFor: 'examples' stamp: 'MU 10/23/2002 16:35'!
example1
	"NmAutoWorldInfoLoader example1."
	| updater |
	updater _ NmAutoWorldInfoLoader new.
	(Delay forMilliseconds: 5000) wait.
	updater release.
	NmAutoWorldInfoLoader flushClient! !


!NmAutoWorldInfoLoader class methodsFor: 'constants' stamp: 'ns 10/3/2002 11:52'!
defaultInterval
	^ self defaultIntervalMsec! !

!NmAutoWorldInfoLoader class methodsFor: 'constants' stamp: 'ns 10/3/2002 12:00'!
defaultIntervalMsec
	^ 10 * 60 * 1000! !

!NmAutoWorldInfoLoader class methodsFor: 'constants' stamp: 'ns 10/8/2002 15:10'!
defaultPriority
	^ Processor userInterruptPriority! !


Object subclass: #NmAvailabilityChecker
	instanceVariableNames: 'updateProcess intervalMinutes availableUrls '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-Network-RPC'!

!NmAvailabilityChecker methodsFor: 'initialize-release' stamp: 'MU 10/22/2002 15:28'!
initialize
	self initializeAvailableUrls! !

!NmAvailabilityChecker methodsFor: 'initialize-release' stamp: 'MU 10/22/2002 15:28'!
initializeAvailableUrls
	availableUrls _ OrderedCollection new! !


!NmAvailabilityChecker methodsFor: 'actions' stamp: 'ka 2/17/2003 16:15'!
checkAvailability
	| isAvailable urls |
	NmSettings useAvailabilityChecker
		ifFalse: [availableUrls _ NmWorldMap map values copy.
			^ self].
	urls _ OrderedCollection new.
	NmWorldMap map values copy
		do: [:url | 
			isAvailable _ self isAvailableAddress: url ipAddress port: url port.
			isAvailable
				ifTrue: [urls add: url]].
	availableUrls _ urls! !

!NmAvailabilityChecker methodsFor: 'actions' stamp: 'MU 10/22/2002 14:55'!
isRunning
	^updateProcess notNil	! !

!NmAvailabilityChecker methodsFor: 'actions' stamp: 'ka 12/18/2002 14:50'!
start
	[self checkAvailability] fork.
	updateProcess notNil
		ifTrue: [updateProcess terminate].
	updateProcess _ [[| currentValue nextValue | 
			currentValue _ Time millisecondClockValue.
			nextValue _ self nextMillisecondClockValue.
			(Delay forMilliseconds: nextValue - currentValue) wait.
			true]
				whileTrue: [self checkAvailability]] newProcess.
	updateProcess priority: self class defaultPriority.
	updateProcess resume! !

!NmAvailabilityChecker methodsFor: 'actions' stamp: 'MU 10/22/2002 14:55'!
stop
	updateProcess notNil
		ifTrue: [updateProcess terminate].
	updateProcess _ nil
! !

!NmAvailabilityChecker methodsFor: 'actions' stamp: 'MU2 1/17/2003 19:52'!
survivorsDo: aBlock 
	"NmAvailabilityChecker default survivorsDo: [:each | Transcript cr; show: each]"
	| urlsOfMap |
	urlsOfMap _ NmWorldMap map values
				collect: [:mapUrl | mapUrl asString].
	(self availableUrls
		select: [:availableUrl | urlsOfMap includes: availableUrl asString])
		do: [:url | aBlock value: url]! !


!NmAvailabilityChecker methodsFor: 'accessing' stamp: 'MU 10/22/2002 15:33'!
availableUrls
	^availableUrls! !

!NmAvailabilityChecker methodsFor: 'accessing' stamp: 'MU 10/22/2002 14:59'!
intervalMinutes
	intervalMinutes
		ifNil: [intervalMinutes _ self class defaultIntervalMinutes].
	^ intervalMinutes! !

!NmAvailabilityChecker methodsFor: 'accessing' stamp: 'ka 10/24/2002 14:38'!
intervalMinutes: minutes 
	intervalMinutes _ minutes.
	self start! !


!NmAvailabilityChecker methodsFor: 'private' stamp: 'MU2 1/21/2003 18:46'!
isAvailableAddress: ipAddressString port: port 
	"NmAvailabilityChecker default isAvailableAddress: '172.25.0.68' port: 4649."
	"NmAvailabilityChecker default isAvailableAddress: NmUtil localAddress port: NmSettings warpPort."
	| result socket |
	ipAddressString isNil ifTrue: [^false].
	result _ false.
	socket _ Socket new.
	[socket
		connectTo: (NetNameResolver addressFromString: ipAddressString)
		port: port.
	socket
		waitForConnectionUntil: (Socket deadlineSecs: self class defaultDeadlineSeconds).
	result _ socket isConnected]
		ensure: [socket closeAndDestroy].
	^ result! !

!NmAvailabilityChecker methodsFor: 'private' stamp: 'MU 10/22/2002 15:08'!
nextMillisecondClockValue
	^ Time millisecondClockValue + (self intervalMinutes * 60 * 1000) truncated! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmAvailabilityChecker class
	instanceVariableNames: 'default isDebugging '!

!NmAvailabilityChecker class methodsFor: 'constants' stamp: 'MU 10/22/2002 14:57'!
defaultDeadlineSeconds
	^1! !

!NmAvailabilityChecker class methodsFor: 'constants' stamp: 'ka 10/24/2002 18:34'!
defaultIntervalMinutes
	^ 0.2! !

!NmAvailabilityChecker class methodsFor: 'constants' stamp: 'MU 10/22/2002 14:57'!
defaultPriority
	^ Processor userInterruptPriority! !


!NmAvailabilityChecker class methodsFor: 'instance creation' stamp: 'MU 10/22/2002 15:29'!
default
	default
		ifNil: [default _ self basicNew initialize].
	^ default! !

!NmAvailabilityChecker class methodsFor: 'instance creation' stamp: 'MU 10/22/2002 15:29'!
new
	^self shouldNotImplement! !


!NmAvailabilityChecker class methodsFor: 'class initialization' stamp: 'mu 12/11/2002 10:45'!
initialize
	"NmAvailabilityChecker initialize"
	default _ nil.
	isDebugging _ true! !


!NmAvailabilityChecker class methodsFor: 'accessing' stamp: 'mu 12/11/2002 10:46'!
isDebugging
	^isDebugging! !

!NmAvailabilityChecker class methodsFor: 'accessing' stamp: 'mu 12/11/2002 10:46'!
isDebugging: aBoolean
	isDebugging _ aBoolean! !


NmpGenericConnector subclass: #NmRemoteConnector
	instanceVariableNames: ''
	classVariableNames: 'CriticalSemaphore '
	poolDictionaries: ''
	category: 'NM-Network-RPC'!

!NmRemoteConnector methodsFor: 'calling' stamp: 'kuri-t 1/24/2003 14:06'!
callCatchAndGo: morphByteArray 
	| ret |
	ret _ nil.
	NmProcessManager
		critical: [ret _ self basicCallCatchAndGo: morphByteArray]
		ifError: [:ex | 
			NmProcessManager releaseAllLockedProcesses.
			ex pass].
	^ ret! !

!NmRemoteConnector methodsFor: 'calling' stamp: 'MU 12/29/2002 17:43'!
callCatchAndGo: morphByteArray x: x y: y 
	| ret |
	ret _ nil.
	NmProcessManager
		critical: [ret _ self
						basicCallCatchAndGo: morphByteArray
						x: x
						y: y]
		ifError: [:ex | 
			NmProcessManager releaseAllLockedProcesses.
			ex pass].
	^ ret! !

!NmRemoteConnector methodsFor: 'calling' stamp: 'MU 12/29/2002 17:43'!
callDispatch: uuidString to: target selector: selector 
	| ret |
	ret _ nil.
	NmProcessManager
		critical: [ret _ self
						basicCallDispatch: uuidString
						to: target
						selector: selector]
		ifError: [:ex | 
			NmProcessManager releaseAllLockedProcesses.
			ex pass].
	^ ret! !

!NmRemoteConnector methodsFor: 'calling' stamp: 'MU 12/29/2002 17:44'!
callDispatch: uuidString to: target selector: selector withArguments: arguments 
	| ret |
	ret _ nil.
	NmProcessManager
		critical: [ret _ self
						basicCallDispatch: uuidString
						to: target
						selector: selector
						withArguments: arguments]
		ifError: [:ex | 
			NmProcessManager releaseAllLockedProcesses.
			ex pass].
	^ ret! !

!NmRemoteConnector methodsFor: 'calling' stamp: 'MU 12/29/2002 17:44'!
callFindBy: uuidString 
	| ret |
	ret _ nil.
	NmProcessManager
		critical: [ret _ self basicCallFindBy: uuidString]
		ifError: [:ex | 
			NmProcessManager releaseAllLockedProcesses.
			ex pass].
	^ ret! !


!NmRemoteConnector methodsFor: 'actions' stamp: 'mu 12/26/2002 23:55'!
close
	isConnected
		ifTrue: [| key | 
			key _ ipAddress , ':' , port printString.
			self class connectionPool
				removeKey: key
				ifAbsent: [].
			super close]! !


!NmRemoteConnector methodsFor: 'initialize' stamp: 'MU2 12/19/2002 19:31'!
connect: ipAddressOrHost port: portNumber timeout: timeoutSeconds 
	| ret |
	ret _ nil.
	NmProcessManager
		critical: [ret _ super
						connect: ipAddressOrHost
						port: portNumber
						timeout: timeoutSeconds]
		ifError: [:ex | 
			NmProcessManager releaseAllLockedProcesses.
			ex pass].
	^ ret! !


!NmRemoteConnector methodsFor: 'private' stamp: 'mu 12/27/2002 02:53'!
signalExceptionFrom: exceptionArray 
	| exception |
	exception _ self buildExceptionFrom: exceptionArray.
	exception class name = #NmNoSuchMorph
		ifTrue: [| localMorph | 
			localMorph _ NmFinder
						findMorphBy: exception uuidString
						ifNone: [].
			localMorph notNil
				ifTrue: [
			Transcript cr;cr; show: 'Unneeded exception so just ignore...'.
		"Unneeded exception so just ignore..." ^ self]].
	exception signal! !


!NmRemoteConnector methodsFor: 'private-calling' stamp: 'mu 2/20/2003 15:24'!
basicCallCatchAndGo: morphByteArray 
	^ self
		send: morphByteArray
		command: 'catchAndGo:'
		by: #NONE! !

!NmRemoteConnector methodsFor: 'private-calling' stamp: 'MU 12/29/2002 15:41'!
basicCallCatchAndGo: morphByteArray x: x y: y 
	| args |
	args _ {morphByteArray. x. y}.
	^ self
		send: args
		command: 'catchAndGo:x:y:'
		by: #DataStream! !

!NmRemoteConnector methodsFor: 'private-calling' stamp: 'MU 12/29/2002 15:40'!
basicCallDispatch: uuidString to: target selector: selector 
	| args |
	args _ {uuidString. target. selector}.
	^ self
		send: args
		command: 'dispatch:to:selector:'
		by: #ReferenceStream! !

!NmRemoteConnector methodsFor: 'private-calling' stamp: 'MU 12/29/2002 15:40'!
basicCallDispatch: uuidString to: target selector: selector withArguments: arguments 
	| args |
	args _ {uuidString. target. selector. arguments}.
	^ self
		send: args
		command: 'dispatch:to:selector:withArguments:'
		by: #ReferenceStream! !

!NmRemoteConnector methodsFor: 'private-calling' stamp: 'MU 12/29/2002 15:40'!
basicCallFindBy: uuidString 
	| args |
	args _ {uuidString}.
	^ self
		send: args
		command: 'findBy:'
		by: #DataStream! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmRemoteConnector class
	instanceVariableNames: 'connectionPool '!

!NmRemoteConnector class methodsFor: 'instance creation' stamp: 'mu 12/11/2002 11:21'!
connect: ipAddressOrHost port: portNumber timeout: timeoutSeconds
	| key connector |
	key _ ipAddressOrHost , ':' , portNumber printString.
	(connectionPool includesKey: key)
		ifTrue: [connector _ connectionPool at: key.
			connector socketIsSafe
				ifFalse: [connector close.
					connector connect: ipAddressOrHost port: portNumber timeout: timeoutSeconds]]
		ifFalse: [connector _ super connect: ipAddressOrHost port: portNumber timeout: timeoutSeconds.
			connector socketIsSafe
				ifTrue: [connectionPool at: key put: connector]].
	^ connector! !


!NmRemoteConnector class methodsFor: 'constants' stamp: 'MU 12/3/2002 11:39'!
defaultPort
	^44445! !


!NmRemoteConnector class methodsFor: 'utility' stamp: 'MU2 1/21/2003 16:53'!
callFindBy: uuid retry: numberOfRetries 
	numberOfRetries
		timesRepeat: [NmAvailabilityChecker default
				survivorsDo: [:url | 
					| connector return | 
					connector _ self connect: url hostOrIpAddress port: url port.
					return _ [connector callFindBy: uuid asString]
								on: NmpGenericError
								do: [:ex | 
									Transcript cr; show: '#callFindBy: cannot find: ' , uuid asString.
									ex return: nil].
					return isNil
						ifFalse: [^ return]].
			(Delay forSeconds: 1) wait].
	^ nil! !

!NmRemoteConnector class methodsFor: 'utility' stamp: 'mu 12/4/2002 18:20'!
closeAllConnections
	self connectionPool
		valuesDo: [:each | each close]! !


!NmRemoteConnector class methodsFor: 'accessing' stamp: 'MU 11/29/2002 15:57'!
connectionPool
	^connectionPool! !


!NmRemoteConnector class methodsFor: 'class initialization' stamp: 'MU 11/29/2002 17:16'!
initialize
	"NmRemoteConnector initialize"
	connectionPool _ Dictionary new! !


NmpGenericServer subclass: #NmRemoteServer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-Network-RPC'!

!NmRemoteServer methodsFor: 'factory' stamp: 'MU 11/29/2002 16:54'!
receptorClass
	^NmServiceHandler! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmRemoteServer class
	instanceVariableNames: ''!

!NmRemoteServer class methodsFor: 'constants' stamp: 'MU 12/3/2002 11:38'!
defaultPort
	^44445! !


NmpGenericReceptor subclass: #NmServiceHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-Network-RPC'!

!NmServiceHandler methodsFor: 'service find' stamp: 'mu 12/6/2002 10:30'!
findBy: uuidString
	^self class finder findBy: uuidString! !


!NmServiceHandler methodsFor: 'service dispatch' stamp: 'mu 12/6/2002 10:30'!
dispatch: uuidString to: target selector: selector
	^self class dispatcher dispatch: uuidString to: target selector: selector
	! !

!NmServiceHandler methodsFor: 'service dispatch' stamp: 'mu 12/6/2002 10:30'!
dispatch: uuidString to: target selector: selector withArguments: arguments 
	^self class dispatcher dispatch: uuidString to: target selector: selector withArguments: arguments ! !


!NmServiceHandler methodsFor: 'service warp' stamp: 'kuri-t 1/24/2003 15:49'!
catchAndGo: morphByteArray 
	^ self class catcher catchAndGo: morphByteArray! !

!NmServiceHandler methodsFor: 'service warp' stamp: 'mu 12/6/2002 10:29'!
catchAndGo: morphByteArray x: x y: y 
	
	^self class catcher catchAndGo: morphByteArray x: x y: y ! !


!NmServiceHandler methodsFor: 'actions' stamp: 'mu 2/20/2003 15:55'!
handleReceived: object semantic: semanticString command: commandString encoder: encoderString 
	| args |
	super
		handleReceived: object
		semantic: semanticString
		command: commandString
		encoder: encoderString.
	(commandString = 'ERROR' or: [commandString = 'RETURN']) ifTrue: [^ nil].
	
	args _ object.
	commandString = 'catchAndGo:' ifTrue: [args _ Array with: object].
	
	^ [self perform: commandString asSymbol withArguments: args]
		on: MessageNotUnderstood
		do: [:ex | 
			self class log: ex.
			self returnError: ex.
			ex return: nil]! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmServiceHandler class
	instanceVariableNames: 'catcher dispatcher finder '!

!NmServiceHandler class methodsFor: 'accessing' stamp: 'MU 11/29/2002 16:52'!
catcher
	^catcher! !

!NmServiceHandler class methodsFor: 'accessing' stamp: 'MU 11/29/2002 16:52'!
dispatcher 
	^dispatcher! !

!NmServiceHandler class methodsFor: 'accessing' stamp: 'MU 11/29/2002 16:52'!
finder   
	^finder  ! !


!NmServiceHandler class methodsFor: 'class initialization' stamp: 'MU 11/29/2002 16:52'!
initialize
	"NmServiceHandler initialize"
	catcher _ NmCatcher new.
	dispatcher _ NmDispatcher new.
	finder _ NmFinder new! !

!NmServiceHandler class methodsFor: 'class initialization' stamp: 'MU 12/2/2002 18:05'!
initializeForDebug
	"NmServiceHandler initializeForDebug"
	catcher _ NmMockCatcher new.
	dispatcher _ NmMockDispatcher new.
	finder _ NmMockFinder new! !

NmAvailabilityChecker initialize!
NmRemoteConnector initialize!
NmServiceHandler initialize!