Object subclass: #NmInitializer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-Support-Client'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmInitializer class
	instanceVariableNames: ''!

!NmInitializer class methodsFor: 'class initialization' stamp: 'MU2 1/21/2003 18:04'!
initialize
	"NmInitializer initialize"
	Smalltalk addToStartUpList: self.
	Smalltalk addToShutDownList: self.
	Vocabulary initialize! !

!NmInitializer class methodsFor: 'class initialization' stamp: 'mu 11/20/2002 12:04'!
obsolete
	
	Smalltalk removeFromStartUpList: self.
	Smalltalk removeFromShutDownList: self.! !


!NmInitializer class methodsFor: 'startup actions'!
removeObsoletePlayerClasses
	"NmInitializer removeObsoletePlayerClasses"
	| obsoleteClasses |
	Smalltalk obsoleteClasses
		do: [:obsoleteClass | 
			| obsoleteClassName | 
			obsoleteClassName _ obsoleteClass name.
			('*Player*' match: obsoleteClassName)
				ifTrue: [obsoleteClass removeFromSystemUnlogged.
					Transcript cr; show: '>> An obsolete player class: ' , obsoleteClassName , ' is removed.']].
	obsoleteClasses _ Smalltalk obsoleteClasses.
	obsoleteClasses size > 0
		ifTrue: [Transcript cr; show: '>> Obsolete classes that still exist: '.
			obsoleteClasses
				do: [:obsoleteClass | Transcript cr; tab; show: obsoleteClass name]]! !


!NmInitializer class methodsFor: 'system startup' stamp: 'ns 1/23/2003 11:51'!
initializeForNet
	NmSettings initializeForNet.
	NmUrl initialize.
	NmNameResolver initialize.
	[NmUtil updateClientIPAddress.
	NmAutoWorldInfoLoader default start.
	NmAvailabilityChecker default start]
		on: SoapImplError, NmpGenericError
		do: [:ex | 
			self inform: 'NetMorph: network initialize failed!!'.
			ex pass].
	NmRemoteConnector initialize! !

!NmInitializer class methodsFor: 'system startup' stamp: 'ka 1/16/2003 15:41'!
startUp
	"NmInitializer startUp"
	self initializeForNet.
	NmFlapSetup addFlap.
	NmProcessManager initialize.
	Player freeUnreferencedSubclasses.
	self removeObsoletePlayerClasses.
	PaintBoxMorph classPool at: #RecentColors put: nil.
	Transcript cr; show: self name , ': initialize success'! !


!NmInitializer class methodsFor: 'system shutdown' stamp: 'ns 1/23/2003 14:40'!
shutDown
	NmAvailabilityChecker default stop.
	NmRemoteConnector closeAllConnections.
	NmServerManager stopWarpServer.
	NmProcessManager releaseAllLockedProcesses! !


NmAbstractSettings subclass: #NmSettings
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-Support-Client'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmSettings class
	instanceVariableNames: ''!

!NmSettings class methodsFor: 'accessing' stamp: 'kuri-t 2/20/2003 15:56'!
interval
	| milliSec |
	milliSec _ self properties at: #interval ifAbsentPutValue: self defaultInterval.
	^ (milliSec / 1000 / 60) asFloat! !

!NmSettings class methodsFor: 'accessing' stamp: 'kuri-t 2/20/2003 16:08'!
interval: aValue 
	| aNumber |
	[aNumber _ aValue asNumber * 1000 * 60 max: 1000.
	self properties at: #interval put: aNumber asInteger]
		on: Error
		do: [:ex | ^ false].
	NmAutoWorldInfoLoader default
		interval: (self properties at: #interval).
	self changed: #interval.
	^ true! !

!NmSettings class methodsFor: 'accessing' stamp: 'ns 1/20/2003 19:10'!
mapFromInternet
	^ self properties at: #mapFromInternet ifAbsentPutValue: true! !

!NmSettings class methodsFor: 'accessing' stamp: 'ns 1/20/2003 19:10'!
mapFromInternet: aValue 
	self properties at: #mapFromInternet put: aValue.
	self nameResolverFromInternet: aValue! !

!NmSettings class methodsFor: 'accessing' stamp: 'ns 1/22/2003 19:25'!
mapName
	| mapName |
	mapName _ self properties
				at: #mapName
				ifAbsent: [].
	(mapName isNil
			or: [mapName isEmpty])
		ifTrue: [mapName _ self properties at: #mapName put: self defaultMapName].
	^ mapName! !

!NmSettings class methodsFor: 'accessing' stamp: 'ns 1/22/2003 19:25'!
mapName: aValue 
	(aValue isNil
			or: [aValue asString isEmpty])
		ifTrue: [^ false].
	self properties at: #mapName put: aValue asString.
	self changed: #mapName.
	^ true! !

!NmSettings class methodsFor: 'accessing' stamp: 'kuri-t 2/20/2003 16:34'!
mapPath
	| mapPath |
	mapPath _ self properties
				at: #mapPath
				ifAbsent: [].
	(mapPath isNil
			or: [mapPath isEmpty])
		ifTrue: [mapPath _ self properties at: #mapPath put: self defaultMapPath].
	^ mapPath! !

!NmSettings class methodsFor: 'accessing' stamp: 'kuri-t 2/20/2003 17:26'!
mapPath: aValue 
	(aValue isNil
			or: [aValue asString isEmpty])
		ifTrue: [^ false].
	self properties at: #mapPath put: aValue asString.
	self changed: #mapPath.
	^ true! !

!NmSettings class methodsFor: 'accessing' stamp: 'ns 1/20/2003 19:14'!
mapUrl
	^ self properties at: #mapUrl ifAbsentPutValue: self defaultMapUrl! !

!NmSettings class methodsFor: 'accessing' stamp: 'ns 1/20/2003 19:14'!
mapUrl: aValue 
	self properties at: #mapUrl put: aValue asString.
	self changed: #mapUrl.
	self nameResolverUrl: aValue.
	^ true! !

!NmSettings class methodsFor: 'accessing' stamp: 'ns 1/20/2003 19:15'!
nameResolverFromInternet
	^ self properties at: #nameResolverFromInternet ifAbsentPutValue: true! !

!NmSettings class methodsFor: 'accessing' stamp: 'ns 1/20/2003 19:15'!
nameResolverFromInternet: aValue 
	self properties at: #nameResolverFromInternet put: aValue! !

!NmSettings class methodsFor: 'accessing' stamp: 'ns 1/20/2003 19:18'!
nameResolverUrl
	^ self properties at: #nameResolverUrl ifAbsentPutValue: self defaultNameResolverUrl! !

!NmSettings class methodsFor: 'accessing' stamp: 'MU2 1/21/2003 18:45'!
nameResolverUrl: aValue 
	"NmSettings nameResolverUrl: 'nm://simula'"
	self properties at: #nameResolverUrl put: aValue asString.
	self changed: #nameResolverUrl.
	^ true! !

!NmSettings class methodsFor: 'accessing' stamp: 'MU2 1/21/2003 19:21'!
targetMapServerPort
	^ self properties at: #targetMapServerPort ifAbsentPutValue: self defaultTargetMapServerPort! !

!NmSettings class methodsFor: 'accessing' stamp: 'MU2 1/21/2003 18:21'!
targetMapServerPort: aValue 
	"NmSettings targetMapServerPort: 8080"
	self properties at: #targetMapServerPort put: aValue.
	self changed: #targetMapServerPort.
	self changed: #targetMapServerPortAsString.
	self targetNameResolverServerPort: aValue! !

!NmSettings class methodsFor: 'accessing' stamp: 'MU2 1/21/2003 18:07'!
targetMapServerTransportProtocol
	^ self properties
		at: #targetMapServerTransportProtocol
		ifAbsentPutValue: (self targetMapServerTransportProtocol: self defaultTargetMapServerTransportProtocol)! !

!NmSettings class methodsFor: 'accessing' stamp: 'MU2 1/21/2003 18:07'!
targetMapServerTransportProtocol: transportProtocolSymbol 
	| tp |
	tp _ transportProtocolSymbol asSymbol.
	self properties at: #targetMapServerTransportProtocol put: tp.
	self changed: #targetMapServerTransportProtocol.
	self targetNameResolverTransportProtocol: transportProtocolSymbol.
	^ true! !

!NmSettings class methodsFor: 'accessing' stamp: 'MU2 1/21/2003 18:07'!
targetNameResolverServerPort
	^ self properties at: #targetNameResolverServerPort ifAbsentPutValue: self defaultTargetNameResolverServerPort! !

!NmSettings class methodsFor: 'accessing' stamp: 'MU2 1/21/2003 18:07'!
targetNameResolverServerPort: aValue 
	self properties at: #targetNameResolverServerPort put: aValue! !

!NmSettings class methodsFor: 'accessing' stamp: 'ns 1/22/2003 19:27'!
targetNameResolverTransportProtocol
	^ self properties at: #targetNameResolverTransportProtocol ifAbsentPutValue: self defaultTargetNameResolverServerTransportProtocol! !

!NmSettings class methodsFor: 'accessing' stamp: 'MU2 1/21/2003 18:07'!
targetNameResolverTransportProtocol: transportProtocolSymbol 
	| tp |
	tp _ transportProtocolSymbol asSymbol.
	self properties at: #targetNameResolverTransportProtocol put: tp.
	self changed: #targetNameResolverTransportProtocol.
	^ true! !

!NmSettings class methodsFor: 'accessing' stamp: 'ka 2/17/2003 16:04'!
useAvailabilityChecker
	"self useAvailabilityChecker"
	^ self properties at: #useAvailabilityChecker ifAbsentPutValue: true! !

!NmSettings class methodsFor: 'accessing' stamp: 'ka 2/17/2003 16:23'!
useAvailabilityChecker: boolean 
	boolean == self useAvailabilityChecker
		ifTrue: [^ self].
	self properties at: #useAvailabilityChecker put: boolean == true.
	NmAvailabilityChecker default checkAvailability! !

!NmSettings class methodsFor: 'accessing' stamp: 'kuri-t 2/18/2003 15:44'!
useKeepMoving
	^ properties at: #useKeepMoving ifAbsentPutValue: false! !

!NmSettings class methodsFor: 'accessing' stamp: 'kuri-t 2/18/2003 15:45'!
useKeepMoving: aValue 
	properties at: #useKeepMoving put: aValue! !

!NmSettings class methodsFor: 'accessing' stamp: 'ns 1/20/2003 19:21'!
warpPort
	^ self properties at: #warpPort ifAbsentPutValue: self defaultWarpPort! !

!NmSettings class methodsFor: 'accessing' stamp: 'kuri-t 2/20/2003 17:10'!
warpPort: aValue 
	"NmSettings warpPort: 37458"
	| aNumber |
	[aNumber _ aValue asNumber]
		on: Error
		do: [^ false].
	NmUrl initialize.
	NmServerManager stopWarpServer.
	NmRemoteServer default restart: aNumber.
	self properties at: #warpPort put: aNumber.
	self changed: #warpPort.
	^ true! !

!NmSettings class methodsFor: 'accessing' stamp: 'kuri-t 2/13/2003 16:24'!
warpableInterval
	^ 1000! !


!NmSettings class methodsFor: 'constants' stamp: 'ns 1/22/2003 18:33'!
defaultInterval
	^ NmAutoWorldInfoLoader defaultInterval! !

!NmSettings class methodsFor: 'constants' stamp: 'MU 10/2/2002 14:48'!
defaultMapName
	^ 'WorldMap.csv' copy.! !

!NmSettings class methodsFor: 'constants' stamp: 'ns 9/25/2002 13:58'!
defaultMapPath
	^ FileDirectory default pathName copy! !

!NmSettings class methodsFor: 'constants'!
defaultMapServerPort
	^ 80! !

!NmSettings class methodsFor: 'constants'!
defaultMapServerTransportProtocol
	^ #http
	! !

!NmSettings class methodsFor: 'constants'!
defaultMapUrl
	^ 'http://Smalltalk' copy.! !

!NmSettings class methodsFor: 'constants' stamp: 'MU2 1/21/2003 19:34'!
defaultNameResolverServerPort
	^ self defaultTargetMapServerPort! !

!NmSettings class methodsFor: 'constants' stamp: 'MU 10/23/2002 17:48'!
defaultNameResolverServerTransportProtocol
	^ self defaultMapServerTransportProtocol
	! !

!NmSettings class methodsFor: 'constants' stamp: 'MU 10/23/2002 17:46'!
defaultNameResolverUrl
	^self defaultMapUrl! !

!NmSettings class methodsFor: 'constants'!
defaultPort
	^ 37458! !

!NmSettings class methodsFor: 'constants' stamp: 'kuri-t 10/16/2002 18:50'!
defaultScreenSize
	^ 800 @ 600! !

!NmSettings class methodsFor: 'constants' stamp: 'MU2 1/21/2003 19:30'!
defaultTargetMapPath
	^ FileDirectory default pathName copy! !

!NmSettings class methodsFor: 'constants' stamp: 'MU2 1/21/2003 19:21'!
defaultTargetMapServerPort
	^ 80! !

!NmSettings class methodsFor: 'constants' stamp: 'MU2 1/21/2003 19:30'!
defaultTargetMapServerTransportProtocol
	^ #http
	! !

!NmSettings class methodsFor: 'constants' stamp: 'MU2 1/21/2003 19:34'!
defaultTargetNameResolverServerPort
	^ self defaultTargetMapServerPort! !

!NmSettings class methodsFor: 'constants' stamp: 'MU2 1/21/2003 19:30'!
defaultTargetNameResolverServerTransportProtocol
	^ self defaultMapServerTransportProtocol
	! !

!NmSettings class methodsFor: 'constants' stamp: 'mu 9/18/2002 18:41'!
defaultTransportProtocol
	"^ #http"
	^#sqtp! !

!NmSettings class methodsFor: 'constants'!
defaultWarpPort
	^ 37458! !

!NmSettings class methodsFor: 'constants'!
defaultWarpTransportProtocol
	"^ #http"
	^#sqtp! !

!NmSettings class methodsFor: 'constants'!
defultMapName
	^ 'WorldMap.xml' copy.! !

!NmSettings class methodsFor: 'constants'!
iniFileName
	^'NetMorph.ini' copy! !


!NmSettings class methodsFor: 'class initialization' stamp: 'ns 1/22/2003 18:37'!
initializeForNet

	self warpPort: self warpPort.
	
	! !


!NmSettings class methodsFor: 'storing/loading' stamp: 'ns 1/22/2003 18:47'!
load
	"NmServerSettings load"
	| inst |
	inst _ super load.
	inst warpPort: inst warpPort.
	! !


!NmSettings class methodsFor: 'actions' stamp: 'mu 2/12/2003 16:44'!
toggleMapFromInternet
	self mapFromInternet: (self mapFromInternet not).
	^self mapFromInternet! !

!NmSettings class methodsFor: 'actions' stamp: 'ka 2/17/2003 15:51'!
toggleUseAvailabilityChecker
	self useAvailabilityChecker: self useAvailabilityChecker not.
	^ self useAvailabilityChecker! !


NmAbstractSettingsMorph subclass: #NmSettingsMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-Support-Client'!

!NmSettingsMorph methodsFor: 'actions' stamp: 'ns 1/23/2003 11:35'!
inspectMap
	NmWorldMap map inspect.! !

!NmSettingsMorph methodsFor: 'actions' stamp: 'ns 1/23/2003 11:35'!
loadMap

	NmWorldMap load.! !

!NmSettingsMorph methodsFor: 'actions'!
save
	NmSettings store! !

!NmSettingsMorph methodsFor: 'actions' stamp: 'ns 1/23/2003 11:35'!
storeMap
	NmWorldMap store.! !

!NmSettingsMorph methodsFor: 'actions' stamp: 'ns 1/23/2003 11:36'!
viewMap
	NmWorldMapMorph open! !


!NmSettingsMorph methodsFor: 'factory' stamp: 'kuri-t 2/20/2003 12:06'!
settingClass
	^ self class settingClass! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmSettingsMorph class
	instanceVariableNames: ''!

!NmSettingsMorph class methodsFor: 'private' stamp: 'kuri-t 2/20/2003 17:21'!
createWindow
	"NmSettingsMorph createWindow openInHand."
	| inst textField row checkBox mapButtons window |
	window _ self createSystemWindow.
	(inst _ window findA: self)
		ifNil: [^ self error: 'System Window not found.'].
	row _ self buildRowLabeled: 'map from internet '.
	checkBox _ UpdatingThreePhaseButtonMorph checkBox target: self settingClass;
				 actionSelector: #toggleMapFromInternet;
				 getSelector: #mapFromInternet.
	row addMorphBack: checkBox.
	mapButtons _ self buildMapButtonRowOn: inst.
	row addMorphBack: mapButtons.
	inst addMorphBack: row.
	row _ self buildRowLabeled: 'map url:   '.
	textField _ self buildTextField: #mapUrl.
	row addMorphBack: textField.
	inst addMorphBack: row.
	row _ self buildRowLabeled: 'map name:'.
	textField _ self buildTextField: #mapName.
	row addMorphBack: textField.
	inst addMorphBack: row.
	row _ self buildRowLabeled: 'warp port:'.
	textField _ self buildTextField: #warpPort.
	row addMorphBack: textField.
	inst addMorphBack: row.
	row _ self buildRowLabeled: 'map path: '.
	textField _ self buildTextField: #mapPath.
	row addMorphBack: textField.
	inst addMorphBack: row.
	row _ self buildRowLabeled: 'interval:   '.
	textField _ self buildTextField: #interval.
	row addMorphBack: textField.
	row
		addMorphBack: (self buildRowLabeled: ' minutes').
	inst addMorphBack: row.
	row _ self buildRowLabeled: 'use availability checker: '.
	checkBox _ UpdatingThreePhaseButtonMorph checkBox target: self settingClass;
				 actionSelector: #toggleUseAvailabilityChecker;
				 getSelector: #useAvailabilityChecker.
	row addMorphBack: checkBox.
	inst addMorphBack: row.
	row _ self buildResetDefaultButtonRowOn: inst.
	inst addMorphBack: row.
	window extent: self windowExtent.
	^ window! !


!NmSettingsMorph class methodsFor: 'instance creation' stamp: 'ka 2/17/2003 16:09'!
windowExtent
	^ 350 @ 230! !


!NmSettingsMorph class methodsFor: 'factory' stamp: 'ns 1/22/2003 16:40'!
settingClass
	^ NmSettings! !


!NmSettingsMorph class methodsFor: 'defaults' stamp: 'ns 1/22/2003 17:19'!
labelString
	^ 'NetMorph setting'! !


Object subclass: #NmUtil
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-Support-Client'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmUtil class
	instanceVariableNames: 'netMorphProxyCache platformSymbol '!

!NmUtil class methodsFor: 'class initialization' stamp: 'mu 11/20/2002 12:04'!
initialize
	"NmUtil initialize"

	Smalltalk addToStartUpList: self.
	self flushNetMorphProxyCache
	! !

!NmUtil class methodsFor: 'class initialization' stamp: 'mu 11/20/2002 12:04'!
obsolete
	"NmUtil obsolete"

	Smalltalk removeFromStartUpList: self.
	! !


!NmUtil class methodsFor: 'system' stamp: 'ns 12/10/2002 10:40'!
displayExtent800at600ForWin32
	"NmUtil displayExtent800at600ForWin32."
	NmUtil platformSymbol == #win32
		ifTrue: [self displayExtent: NmSettings defaultScreenSize]! !

!NmUtil class methodsFor: 'system' stamp: 'ns 12/10/2002 10:37'!
displayExtent: extent 
	DisplayScreen
		depth: Display depth
		width: extent x
		height: extent y
		fullscreen: false! !

!NmUtil class methodsFor: 'system' stamp: 'mu 2/20/2003 15:05'!
makeNeighborImage
	"NmUtil makeNeighborImage"
	| oldName |
	NmSettings mapPath: FileDirectory default pathName.
	NmSettings mapFromInternet: false.
	NmWorldMap beTwoNeighbors.
	NmWorldMap store.
	oldName _ (Smalltalk fullNameForImageNamed: Smalltalk imageName)
						upTo: $..
	[NmWorldMap map
		keysAndValuesDo: [:point :nmUrl | | newName |
			newName _ oldName, point asString.
			(SourceFiles at: 2)
				ifNotNil: [Smalltalk
						saveChangesInFileNamed: (Smalltalk fullNameForChangesNamed: newName)].
			Smalltalk
				saveImageInFileNamed: (Smalltalk fullNameForImageNamed: newName).
			NmSettings warpPort: nmUrl port]] on: CannotDeleteFileException do: [:ex | ].! !

!NmUtil class methodsFor: 'system' stamp: 'MU 11/20/2002 10:56'!
platformSymbol
	"NmUtil platformSymbol"
	platformSymbol ifNil: [platformSymbol _ Smalltalk platformName asLowercase asSymbol ].
	^platformSymbol! !

!NmUtil class methodsFor: 'system' stamp: 'MU 11/19/2002 19:20'!
startUp

	platformSymbol := nil.
! !


!NmUtil class methodsFor: 'adapter for Network' stamp: 'mu 10/28/2002 18:04'!
localAddress
	"Squeak specific"
	^NetNameResolver localAddressString.
	! !

!NmUtil class methodsFor: 'adapter for Network' stamp: 'mu 10/28/2002 14:29'!
localHostname
	"Squeak specific"
	"NmUtil localHostname"
	| localHostname |
	localHostname _ NetNameResolver nameForAddress: NetNameResolver localHostAddress timeout: 30.
	localHostname isNil ifTrue: [^''].
	^ localHostname! !

!NmUtil class methodsFor: 'adapter for Network' stamp: 'mu 10/28/2002 16:45'!
unresolvedIPAddressString
	^ '0.0.0.0' copy! !

!NmUtil class methodsFor: 'adapter for Network' stamp: 'kuri-t 12/12/2002 15:50'!
urlFromString: aString 
	| string url |
	(aString isNil or: [aString = '']) ifTrue: [^ nil].
	string _ (aString beginsWith: NmUrl protcolIdentifier , '://')
				ifTrue: [aString]
				ifFalse: [NmUrl protcolIdentifier , '://' , aString].
	[url _ string asUrl]
		on: Error
		do: [:ex | ^ nil].
	^ (url isKindOf: NmUrl)
		ifTrue: [url]! !


!NmUtil class methodsFor: 'NetMorph proxy cache' stamp: 'ka 9/13/2002 16:35'!
flushNetMorphProxyCache
	"NmUtil flushNetMorphProxyCache"
	netMorphProxyCache _ Dictionary new! !

!NmUtil class methodsFor: 'NetMorph proxy cache' stamp: 'ka 9/13/2002 16:34'!
netMorphProxyCache
	"NmUtil netMorphProxyCache"
	^ netMorphProxyCache! !


!NmUtil class methodsFor: 'gzip support' stamp: 'ka 10/15/2002 17:45'!
gunzippedFrom: aByteArray 
	"NmUtil gunzippedFrom: (NmUtil gzippedFrom: 'hello' asByteArray) asString"
	| gzipStream |
	gzipStream _ GZipReadStream on: aByteArray.
	^ gzipStream contents! !

!NmUtil class methodsFor: 'gzip support' stamp: 'ka 10/15/2002 17:42'!
gzippedFrom: aByteArray 
	"NmUtil gzippedFrom: 'hello' asByteArray"
	| bufferStream gZipStream |
	bufferStream _ RWBinaryOrTextStream
				on: (ByteArray new: 5000).
	bufferStream binary.
	gZipStream _ GZipWriteStream on: bufferStream.
	aByteArray
		do: [:each | gZipStream nextPut: each].
	gZipStream close.
	^ bufferStream contents! !


!NmUtil class methodsFor: 'soap support' stamp: 'mu 1/23/2003 19:25'!
updateClientIPAddress
	"NmUtil updateClientIPAddress"
	| localAddress localHostname |
	localAddress _ NmUtil localAddress.
	localHostname _ NmUtil localHostname.
	NmSettings nameResolverFromInternet
		ifTrue: [| call url resp port | 
			url _ NmSettings nameResolverUrl asUrl.
			port _ NmSettings targetNameResolverServerPort.
			call _ (SoapCallEntry
						tcpHost: url authority
						port: (port isNil
								ifTrue: [NmSettings defaultTargetNameResolverServerPort]
								ifFalse: [port])) newCall.
			call targetObjectURI: '/netMorph'.
			call transport: NmSettings targetNameResolverTransportProtocol.
			call methodName: 'updateIPAddress:of:'.
			call
				addParameter: (SoapVariable name: #ipAddress value: localAddress).
			call
				addParameter: (SoapVariable name: #hostname value: localHostname).
			resp _ call invoke.
			resp isFault
				ifTrue: [resp raiseException]
				ifFalse: [NmNameResolver default nameAt: localHostname put: localAddress]]
		ifFalse: [NmNameResolver default nameAt: localHostname put: localAddress].
	Transcript cr; show: '## NmNameResolver was updated'! !

NmInitializer initialize!
NmUtil initialize!