Object subclass: #NmWorldMap
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NM-WorldMap'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

NmWorldMap class
	instanceVariableNames: 'map mapPath '!

!NmWorldMap class methodsFor: 'examples' stamp: 'mu 1/5/2003 23:06'!
example3
	"NmWorldMap example3"
	| worldMap |
	self initialize.
	worldMap _ self map.
	worldMap at: 0 @ 0 put: 'nm://your-w6165vadg7:8823/' asUrl.
	worldMap at: 0 @ 1 put: 'nm://wobbuffet:8823/' asUrl.
	worldMap at: 1 @ 0 put: 'nm://mono:8823/' asUrl .
	worldMap at: 1 @ 1 put: 'nm://dvorak:8823/' asUrl .
	^ worldMap! !


!NmWorldMap class methodsFor: 'accessing'!
map
	^ map! !

!NmWorldMap class methodsFor: 'accessing'!
map: aDictionary
	map _ aDictionary! !


!NmWorldMap class methodsFor: 'actions' stamp: 'mu 1/5/2003 23:07'!
survivorsDo: aBlock 
	"NmWorldMap survivorsDo: [:each | Transcript cr; show: each]"
	(NmAvailabilityChecker default availableUrls
		select: [:availableUrl | (self map values
				collect: [:mapUrl | mapUrl asString])
				includes: availableUrl asString])
		do: [:url | aBlock value: url]! !


!NmWorldMap class methodsFor: 'class initialization'!
initialize
	"NmWorldMap initialize"
	map _ Dictionary new.
	
	
	! !


!NmWorldMap class methodsFor: 'storing/loading' stamp: 'ns 1/23/2003 14:56'!
load
	"NmWorldMap load"
	| mapString localUrl |
	NmSettings mapFromInternet
		ifTrue: [| call url resp port | 
			url _ NmSettings mapUrl asUrl.
			port _ url port.
			call _ (SoapCallEntry
						tcpHost: url authority
						port: (port isNil
								ifTrue: [NmSettings defaultTargetMapServerPort]
								ifFalse: [port])) newCall.
			call targetObjectURI: '/netMorph'.
			call encoding: #soapSqEncoding.
			call methodName: 'getMapStringNamed:'.
			call
				addParameter: (SoapVariable name: #mapName value: NmSettings mapName).
			resp _ call invoke.
			mapString _ resp isFault
						ifTrue: [resp raiseException.
							nil]
						ifFalse: [resp returnValue].
			mapString isNil
				ifFalse: [self fromCSVString: mapString]]
		ifFalse: [mapString _ NmWorldMapReadWriter getMapStringFromFile: NmSettings mapName.
			mapString isNil
				ifFalse: [self fromCSVString: mapString]].
	Transcript cr; show: '## NmWorldMap was loaded: ' , self map printString.
	localUrl _ self map values
				detect: [:each | each asString = NmUrl local asString]
				ifNone: [^ self].
	localUrl isLocal: true! !

!NmWorldMap class methodsFor: 'storing/loading'!
loadFromXmlString: xmlString
	^Object readSixxFrom: xmlString! !

!NmWorldMap class methodsFor: 'storing/loading' stamp: 'ns 1/23/2003 14:56'!
store
	"NmWorldMap store"
	NmSettings mapFromInternet
		ifTrue: [| call url resp port | 
			url _ NmSettings mapUrl asUrl.
			port _ url port.
			call _ (SoapCallEntry
						tcpHost: url authority
						port: (port isNil
								ifTrue: [NmSettings defaultTargetMapServerPort]
								ifFalse: [port])) newCall.
			call targetObjectURI: '/netMorph'.
			call encoding: #soapSqEncoding.
			call methodName: 'putMapString:named:'.
			call
				addParameter: (SoapVariable name: #mapCSVString value: self csvString).
			call
				addParameter: (SoapVariable name: #mapName value: NmSettings mapName).
			resp _ call invoke.
			resp isFault
				ifTrue: [resp raiseException]
				ifFalse: [resp returnValue]]
		ifFalse: [NmWorldMapReadWriter  putMapString: self csvString toFile: NmSettings mapName]! !

!NmWorldMap class methodsFor: 'storing/loading'!
storeXmlString
	^self map sixxString! !


!NmWorldMap class methodsFor: 'map accessing' stamp: 'mu 1/5/2003 23:19'!
bottomOf: address 
	"NmWorldMap bottomOf: 'nm://smalltalk:37458/' asUrl"
	| point destinationPoint |
	point _ self pointOf: address.
	point isNil
		ifTrue: [^ nil].
	destinationPoint _ Point x: point x y: point y - 1.
	^ map
		at: destinationPoint
		ifAbsent: [^ nil]! !

!NmWorldMap class methodsFor: 'map accessing' stamp: 'mu2 11/25/2002 17:47'!
deltaPointFrom: fromUrl to: toUrl 
	"NmWorldMap deltaPointFrom: 'nm://lisp:37458' asUrl to: 
	'nm://lisp:37459' asUrl  800@0"
	| fromPoint toPoint |
	fromPoint _ self pointOf: fromUrl.
	toPoint _ self pointOf: toUrl.
	^ toPoint - fromPoint * (ActiveWorld extent) * (1 @ -1)! !

!NmWorldMap class methodsFor: 'map accessing' stamp: 'mu 1/5/2003 23:19'!
leftOf: address 
	"NmWorldMap leftOf: 'nm://smalltalk:37458/' asUrl"
	| point destinationPoint |
	point _ self pointOf: address.
	point isNil
		ifTrue: [^ nil].
	destinationPoint _ Point x: point x - 1 y: point y.
	^ map
		at: destinationPoint
		ifAbsent: [^ nil]! !

!NmWorldMap class methodsFor: 'map accessing' stamp: 'mu 1/6/2003 00:10'!
pointOf: url 
	"NmWorldMap pointOf: 'nm://Smalltalk:37458/' asUrl"
	"NmWorldMap pointOf: 'nm://172.25.0.80:37458/' asUrl"
	^map
		keyAtValue: url
		ifAbsent: [^ nil]! !

!NmWorldMap class methodsFor: 'map accessing' stamp: 'mu 1/5/2003 23:19'!
rightOf: address 
	"NmWorldMap rightOf: 'nm://smalltalk:37458/' asUrl"
	| point destinationPoint |
	point _ self pointOf: address.
	point isNil
		ifTrue: [^ nil].
	destinationPoint _ Point x: point x + 1 y: point y.
	^ map
		at: destinationPoint
		ifAbsent: [^ nil]! !

!NmWorldMap class methodsFor: 'map accessing' stamp: 'mu 1/5/2003 23:19'!
topOf: address 
	"NmWorldMap topOf: 'nm://smalltalk:37458/' asUrl"
	| point destinationPoint |
	point _ self pointOf: address.
	point isNil
		ifTrue: [^ nil].
	destinationPoint _ Point x: point x y: point y + 1.
	^ map
		at: destinationPoint
		ifAbsent: [^ nil]! !


!NmWorldMap class methodsFor: 'obsolete' stamp: 'mu 1/5/2003 23:12'!
example1
	"NmWorldMap example1"
	| worldMap |
	self initialize.
	worldMap _ self map.
	worldMap at: 0 @ 1 put: #topLeft .
	worldMap at: 1 @ 1 put: #topRight.
	worldMap at: 0 @ 0 put: #bottomLeft.
	worldMap at: 1 @ 0 put: #bottomRight! !

!NmWorldMap class methodsFor: 'obsolete' stamp: 'mu 1/5/2003 23:13'!
example2
	"NmWorldMap example2"
	| worldMap |
	self initialize.
	worldMap _ self map.
	worldMap at: 0 @ 0 put: 'your-w6165vadg7' asLowercase .
	worldMap at: 1 @ 0 put: 'mono' asLowercase ! !

!NmWorldMap class methodsFor: 'obsolete' stamp: 'mu 1/5/2003 23:13'!
preparePlayfields
	"NmWorldMap preparePlayfields"
	| width height space |
	width _ 300.
	height _ 240.
	space _ 20.
	self example1.
	self map
		associationsDo: [:assoc | 
			| x y playfield | 
			x _ assoc key x * (width + space).
			y _ assoc key y negated + 1 * (height + space).
			playfield _ PasteUpMorph new.
			playfield name: assoc value.
			playfield fenceEnabled: false.
			playfield width: width.
			playfield height: height.
			playfield position: x @ y.
			playfield openInWorld]! !


!NmWorldMap class methodsFor: 'converting' stamp: 'ns 1/23/2003 14:27'!
csvString
	"NmWorldMap csvString"
	^ NmWorldMapReadWriter csvStringFrom: map! !

!NmWorldMap class methodsFor: 'converting' stamp: 'ns 1/23/2003 14:27'!
fromCSVString: aString 

	self map: (NmWorldMapReadWriter parseCSVString: aString).
	! !


!NmWorldMap class methodsFor: 'utilities' stamp: 'mu 1/6/2003 00:11'!
csvStringFrom: mapDictionary 
	| stream |
	stream _ WriteStream on: String new.
	mapDictionary
		keysAndValuesDo: [:key :value | 
			stream nextPutAll: key printString.
			stream nextPut: $,.
			stream nextPutAll: value csvString.
			stream nextPut: Character cr].
	^ stream contents! !

!NmWorldMap class methodsFor: 'utilities' stamp: 'mu 1/5/2003 23:23'!
parseCSVString: aString
	| newMap stream |
	newMap := Dictionary new.
	stream _ ReadStream on: aString.
	[stream atEnd]
		whileFalse: [| line lineStream url point | 
			line _ stream nextLine.
			(line includes: $,)
				ifTrue: [lineStream _ ReadStream on: line.
					point _ Point readFrom: ((lineStream upTo: $,) withBlanksTrimmed).
					url _ lineStream upToEnd withBlanksTrimmed asUrl.
					newMap at: point put: url]].
	^newMap! !


!NmWorldMap class methodsFor: 'prototype' stamp: 'mu 1/17/2003 14:51'!
beTwoNeighbors
	"NmWorldMap beTwoNeighbors"
	| newMap |
	newMap _ Dictionary new.
	newMap at: 0@0 put: NmUrl local.
	newMap at: 1@0 put: (NmUrl local copy port: NmUrl local port + 1).
	self map: newMap.
	^self! !

NmWorldMap initialize!